==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/fr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Le partage de serveur à serveur n'est pas activé sur ce serveur",
    "The mountpoint name contains invalid characters." : "Le nom du point de montage contient des caractères non valides.",
    "Not allowed to create a federated share with the same user server" : "Non autorisé à créer un partage fédéré avec un utilisateur du même serveur",
    "Invalid or untrusted SSL certificate" : "Certificat SSL non valable ou non fiable",
    "Could not authenticate to remote share, password might be wrong" : "Impossible de s'authentifier au partage distant : le mot de passe en probablement incorrect",
    "Storage not valid" : "Support de stockage non valide",
    "Couldn't add remote share" : "Impossible d'ajouter le partage distant",
    "Shared with you" : "Partagés avec vous",
    "Shared with others" : "Partagés avec d'autres",
    "Shared by link" : "Partagés par lien",
    "Federated sharing" : "Federated sharing",
    "Nothing shared with you yet" : "Aucun fichier n'est partagé avec vous pour l'instant",
    "Files and folders others share with you will show up here" : "Les fichiers et dossiers partagés avec vous apparaîtront ici",
    "Nothing shared yet" : "Rien n'est partagé pour l'instant",
    "Files and folders you share will show up here" : "Les fichiers et dossiers que vous partagez apparaîtront ici",
    "No shared links" : "Aucun partage par lien",
    "Files and folders you share by link will show up here" : "Les fichiers et dossiers que vous partagez par lien apparaîtront ici",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voulez-vous ajouter le partage distant {name} de {owner}@{remote} ?",
    "Remote share" : "Partage distant",
    "Remote share password" : "Mot de passe du partage distant",
    "Cancel" : "Annuler",
    "Add remote share" : "Ajouter un partage distant",
    "You can upload into this folder" : "Vous pouvez téléverser dans ce dossier",
    "No ownCloud installation (7 or higher) found at {remote}" : "Aucune installation ownCloud (7 ou supérieur) trouvée sur {remote}",
    "Invalid ownCloud url" : "URL ownCloud non valide",
    "Shared by" : "Partagé par",
    "Sharing" : "Partage",
    "A file or folder has been <strong>shared</strong>" : "Un fichier ou un répertoire a été <strong>partagé</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un fichier ou un répertoire a été partagé depuis <strong>un autre serveur</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un fichier ou un répertoire partagé publiquement a été <strong>téléchargé</strong>",
    "You received a new remote share %2$s from %1$s" : "L'utilisateur %1$s a partagé la ressource distante %2$s avec vous",
    "You received a new remote share from %s" : "Vous avez reçu un partage distant de %s",
    "%1$s accepted remote share %2$s" : "%1$s a accepté le partage distant %2$s",
    "%1$s declined remote share %2$s" : "%1$s a refusé le partage distant %2$s",
    "%1$s unshared %2$s from you" : "%1$s a cessé de partager %2$s avec  vous",
    "Public shared folder %1$s was downloaded" : "Le dossier public %1$s a été téléchargé",
    "Public shared file %1$s was downloaded" : "Le fichier public %1$s a été téléchargé",
    "You shared %1$s with %2$s" : "Vous avez partagé %1$s avec %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s a partagé %1$s avec %3$s",
    "You removed the share of %2$s for %1$s" : "Vous avez supprimé le partage de %2$s pour %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s a supprimé votre partage de %3$s pour %1$s",
    "You shared %1$s with group %2$s" : "Vous avez partagé %1$s avec le groupe %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s partagé %1$s avec le groupe %3$s",
    "You removed the share of group %2$s for %1$s" : "Vous avez supprimé le partage du groupe %2$s pour %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s a supprimé le partage du groupe %3$s pour %1$s",
    "%2$s shared %1$s via link" : "%2$s a partagé %1$s par lien",
    "You shared %1$s via link" : "Vous avez partagé %1$s par lien public",
    "You removed the public link for %1$s" : "Vous avez supprimé le lien public pour %1$s",
    "%2$s removed the public link for %1$s" : "%2$s a supprimé le lien public pour %1$s",
    "Your public link for %1$s expired" : "Le lien public pour %1$s a expiré",
    "The public link of %2$s for %1$s expired" : "Le lien public de %2$s pour %1$s a expiré",
    "%2$s shared %1$s with you" : "%2$s a partagé %1$s avec vous",
    "%2$s removed the share for %1$s" : "%2$s a supprimé le partage pour %1$s",
    "Downloaded via public link" : "Téléchargé par lien public",
    "Shared with %2$s" : "Partagé avec %2$s",
    "Shared with %3$s by %2$s" : "Partagé avec %3$s par %2$s",
    "Removed share for %2$s" : "Partage supprimé pour %2$s",
    "%2$s removed share for %3$s" : "%2$s a supprimé le partage pour %3$s",
    "Shared with group %2$s" : "Partagé avec le groupe %2$s",
    "Shared with group %3$s by %2$s" : "Partagé avec le groupe %3$s par %2$s",
    "Removed share of group %2$s" : "Partage supprimé du groupe %2$s",
    "%2$s removed share of group %3$s" : "%2$s a supprimé le partage du groupe %3$s",
    "Shared via link by %2$s" : "Partagé via lien par %2$s",
    "Shared via public link" : "Partagé par lien public",
    "Removed public link" : "Lien public supprimé",
    "%2$s removed public link" : "%2$s a supprimé le lien public",
    "Public link expired" : "Lien public expiré",
    "Public link of %2$s expired" : "Le lien public de %2$s a expiré",
    "Shared by %2$s" : "Partagé par %2$s",
    "Shares" : "Partages",
    "You received \"/%2$s\" as a remote share from %1$s" : "L'utilisateur %1$s a partagé la ressource distante %2$s avec vous",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon identifiant Federated Cloud #owncloud %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partagez avec moi grâce à mon identifiant Federated Cloud #owncloud",
    "This share is password-protected" : "Ce partage est protégé par un mot de passe",
    "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
    "Password" : "Mot de passe",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Name" : "Nom",
    "Share time" : "Date de partage",
    "Sorry, this link doesn’t seem to work anymore." : "Désolé, mais ce lien semble ne plus fonctionner.",
    "Reasons might be:" : "Les raisons peuvent être :",
    "the item was removed" : "l'élément a été supprimé",
    "the link expired" : "le lien a expiré",
    "sharing is disabled" : "le partage est désactivé",
    "For more info, please ask the person who sent this link." : "Pour plus d'informations, veuillez contacter la personne qui a envoyé ce lien.",
    "Add to your ownCloud" : "Ajouter à votre ownCloud",
    "Download" : "Télécharger",
    "Download %s" : "Télécharger %s",
    "Direct link" : "Lien direct",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Voir la documentation",
    "Allow users on this server to send shares to other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs",
    "Allow users on this server to receive shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages d'autres serveurs",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Votre identifiant Federated Cloud :",
    "Share it:" : "Partager :",
    "Add to your website" : "Ajouter à votre site web",
    "Share with me via ownCloud" : "Partagez avec moi via ownCloud",
    "HTML Code:" : "Code HTML :",
    "Public link of %2$s expired" : "Le lien public de %2$s a expiré",
    "Public shared file %1$s was downloaded" : "Le fichier public %1$s a été téléchargé",
    "Public shared folder %1$s was downloaded" : "Le dossier public %1$s a été téléchargé",
    "Removed share for %2$s" : "Partage supprimé pour %2$s",
    "Removed share of group %2$s" : "Partage supprimé du groupe %2$s",
    "Shared by %2$s" : "Partagé par %2$s",
    "Shared via link by %2$s" : "Partagé via lien par %2$s",
    "Shared with group %3$s by %2$s" : "Partagé avec le groupe %3$s par %2$s",
    "The public link of %2$s for %1$s expired" : "Le lien public de %2$s pour %1$s a expiré",
    "You removed the public link for %1$s" : "Vous avez supprimé le lien public pour %1$s",
    "You removed the share of %2$s for %1$s" : "Vous avez supprimé le partage de %2$s pour %1$s",
    "You removed the share of group %2$s for %1$s" : "Vous avez supprimé le partage du groupe %2$s pour %1$s",
    "Your public link for %1$s expired" : "Le lien public pour %1$s a expiré"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/fr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Le partage de serveur à serveur n'est pas activé sur ce serveur",
    "The mountpoint name contains invalid characters." : "Le nom du point de montage contient des caractères non valides.",
    "Not allowed to create a federated share with the same user server" : "Non autorisé à créer un partage fédéré avec un utilisateur du même serveur",
    "Invalid or untrusted SSL certificate" : "Certificat SSL non valable ou non fiable",
    "Could not authenticate to remote share, password might be wrong" : "Impossible de s'authentifier au partage distant : le mot de passe en probablement incorrect",
    "Storage not valid" : "Support de stockage non valide",
    "Couldn't add remote share" : "Impossible d'ajouter le partage distant",
    "Shared with you" : "Partagés avec vous",
    "Shared with others" : "Partagés avec d'autres",
    "Shared by link" : "Partagés par lien",
    "Uploading..." : "Téléversement en cours…",
    "Nothing shared with you yet" : "Aucun fichier n'est partagé avec vous pour l'instant",
    "Files and folders others share with you will show up here" : "Les fichiers et dossiers partagés avec vous apparaîtront ici",
    "Nothing shared yet" : "Rien n'est partagé pour l'instant",
    "Files and folders you share will show up here" : "Les fichiers et dossiers que vous partagez apparaîtront ici",
    "No shared links" : "Aucun partage par lien",
    "Files and folders you share by link will show up here" : "Les fichiers et dossiers que vous partagez par lien apparaîtront ici",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voulez-vous ajouter le partage distant {name} de {owner}@{remote} ?",
    "Remote share" : "Partage distant",
    "Remote share password" : "Mot de passe du partage distant",
    "Cancel" : "Annuler",
    "Add remote share" : "Ajouter un partage distant",
    "You can upload into this folder" : "Vous pouvez téléverser dans ce dossier",
    "No ownCloud installation (7 or higher) found at {remote}" : "Aucune installation ownCloud (7 ou supérieur) trouvée sur {remote}",
    "Invalid ownCloud url" : "URL ownCloud non valide",
    "Share" : "Partager",
    "No expiration date set" : "Aucune date d'expiration spécifiée",
    "Shared by" : "Partagé par",
    "Sharing" : "Partage",
    "Share API is disabled" : "l'API de partage est désactivée",
    "Wrong share ID, share doesn't exist" : "Mauvais ID de partage, le partage n'existe pas",
    "Could not delete share" : "Impossible de supprimer le partage",
    "Please specify a file or folder path" : "Veuillez spécifier un fichier ou dossier",
    "Wrong path, file/folder doesn't exist" : "Mauvais chemin, Le fichier/dossier n'existe pas",
    "Please specify a valid user" : "Veuillez entrer un utilisateur valide",
    "Group sharing is disabled by the administrator" : "Le partage de groupe a été désactivé par l'administrateur",
    "Please specify a valid group" : "Veuillez entrer un groupe valide",
    "Public link sharing is disabled by the administrator" : "Le partage de lien public a été désactivé par l'administrateur",
    "Public upload disabled by the administrator" : "Téléversement public désactivé par l'administrateur",
    "Public upload is only possible for publicly shared folders" : "Le téléversement public est possible uniquement pour les dossiers partagés publiquement",
    "Invalid date, date format must be YYYY-MM-DD" : "Date invalide, le format doit être YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Le partage %s a échoué parce que l'infrastructure n'autorise pas les partages du type %s",
    "Unknown share type" : "Type de partage inconnu",
    "Not a directory" : "N'est pas un répertoire",
    "Could not lock path" : "Impossible de verrouiller le chemin",
    "Can't change permissions for public share links" : "Impossible de changer les permissions pour les liens de partage public",
    "Wrong or no update parameter given" : "Mauvais ou aucun paramètre donné ",
    "Cannot increase permissions" : "Impossible d'augmenter les permissions",
    "A file or folder has been <strong>shared</strong>" : "Un fichier ou un répertoire a été <strong>partagé</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un fichier ou un répertoire a été partagé depuis <strong>un autre serveur</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un fichier ou un répertoire partagé publiquement a été <strong>téléchargé</strong>",
    "You received a new remote share %2$s from %1$s" : "L'utilisateur %1$s a partagé la ressource distante %2$s avec vous",
    "You received a new remote share from %s" : "Vous avez reçu un partage distant de %s",
    "%1$s accepted remote share %2$s" : "%1$s a accepté le partage distant %2$s",
    "%1$s declined remote share %2$s" : "%1$s a refusé le partage distant %2$s",
    "%1$s unshared %2$s from you" : "%1$s a cessé de partager %2$s avec  vous",
    "Public shared folder %1$s was downloaded" : "Le dossier public %1$s a été téléchargé",
    "Public shared file %1$s was downloaded" : "Le fichier public %1$s a été téléchargé",
    "You shared %1$s with %2$s" : "Vous avez partagé %1$s avec %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s a partagé %1$s avec %3$s",
    "You removed the share of %2$s for %1$s" : "Vous avez supprimé le partage de %2$s pour %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s a supprimé votre partage de %3$s pour %1$s",
    "You shared %1$s with group %2$s" : "Vous avez partagé %1$s avec le groupe %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s partagé %1$s avec le groupe %3$s",
    "You removed the share of group %2$s for %1$s" : "Vous avez supprimé le partage du groupe %2$s pour %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s a supprimé le partage du groupe %3$s pour %1$s",
    "%2$s shared %1$s via link" : "%2$s a partagé %1$s par lien",
    "You shared %1$s via link" : "Vous avez partagé %1$s par lien public",
    "You removed the public link for %1$s" : "Vous avez supprimé le lien public pour %1$s",
    "%2$s removed the public link for %1$s" : "%2$s a supprimé le lien public pour %1$s",
    "Your public link for %1$s expired" : "Le lien public pour %1$s a expiré",
    "The public link of %2$s for %1$s expired" : "Le lien public de %2$s pour %1$s a expiré",
    "%2$s shared %1$s with you" : "%2$s a partagé %1$s avec vous",
    "%2$s removed the share for %1$s" : "%2$s a supprimé le partage pour %1$s",
    "Downloaded via public link" : "Téléchargé par lien public",
    "Shared with %2$s" : "Partagé avec %2$s",
    "Shared with %3$s by %2$s" : "Partagé avec %3$s par %2$s",
    "Removed share for %2$s" : "Partage supprimé pour %2$s",
    "%2$s removed share for %3$s" : "%2$s a supprimé le partage pour %3$s",
    "Shared with group %2$s" : "Partagé avec le groupe %2$s",
    "Shared with group %3$s by %2$s" : "Partagé avec le groupe %3$s par %2$s",
    "Removed share of group %2$s" : "Partage supprimé du groupe %2$s",
    "%2$s removed share of group %3$s" : "%2$s a supprimé le partage du groupe %3$s",
    "Shared via link by %2$s" : "Partagé via lien par %2$s",
    "Shared via public link" : "Partagé par lien public",
    "Removed public link" : "Lien public supprimé",
    "%2$s removed public link" : "%2$s a supprimé le lien public",
    "Public link expired" : "Lien public expiré",
    "Public link of %2$s expired" : "Le lien public de %2$s a expiré",
    "Shared by %2$s" : "Partagé par %2$s",
    "Shares" : "Partages",
    "This share is password-protected" : "Ce partage est protégé par un mot de passe",
    "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
    "Password" : "Mot de passe",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Name" : "Nom",
    "Share time" : "Date de partage",
    "Expiration date" : "Date d'expiration",
    "Sorry, this link doesn’t seem to work anymore." : "Désolé, mais ce lien semble ne plus fonctionner.",
    "Reasons might be:" : "Les raisons peuvent être :",
    "the item was removed" : "l'élément a été supprimé",
    "the link expired" : "le lien a expiré",
    "sharing is disabled" : "le partage est désactivé",
    "For more info, please ask the person who sent this link." : "Pour plus d'informations, veuillez contacter la personne qui a envoyé ce lien.",
    "%s is publicly shared" : "%s est partagé publiquement",
    "Add to your ownCloud" : "Ajouter à votre ownCloud",
    "Download" : "Télécharger",
    "Download %s" : "Télécharger %s",
    "Direct link" : "Lien direct"
},
"nplurals=2; plural=(n > 1);");
